@@ -11,6 +11,8 @@
  *		2 of the License, or (at your option) any later version.
  * ============================================================================
  * Sep 06,  2008 Moises Silva   Initial Version
+ * Nov 20,  2008 Alex Feldman   Added ZT_XLAW
+ * Sep 22,  2009 Moises Silva   Added dahdi_alarm_channel stuff
  ******************************************************************************
  */
 
@@ -22,18 +24,28 @@
 #if defined (DAHDI_ISSUES)
 
 #ifdef __KERNEL__
-#include <dahdi/kernel.h> // this will bring dahdi kernel stuff plus dahdi/user.h and friends
+# include <dahdi/kernel.h> // this will bring dahdi kernel stuff plus dahdi/user.h and friends
+#else
+# include <dahdi/user.h> // this will bring dahdi user stuff
 #endif
 
+
 #ifdef DAHDI_ECHOCANCEL_FAX_MODE 
 #define DAHDI_22
 #else
 #undef DAHDI_22
 #endif
 
+#ifdef DAHDI_AUDIO_NOTIFY
+#define DAHDI_23
+#else
+#undef DAHDI_23
+#endif
+
 // defines 
 #define ZT_CODE DAHDI_CODE
 
+
 #define ZT_ONHOOKTRANSFER DAHDI_ONHOOKTRANSFER
 #define ZT_SETPOLARITY DAHDI_SETPOLARITY
 #define ZT_CHUNKSIZE DAHDI_CHUNKSIZE
@@ -90,7 +102,7 @@
 
 #define ZT_LAW_ALAW DAHDI_LAW_ALAW
 #define ZT_LAW_MULAW DAHDI_LAW_MULAW
-#define ZT_XLAW	DAHDI_XLAW     
+#define ZT_XLAW	DAHDI_XLAW
 
 #define ZT_MAINT_REMOTELOOP DAHDI_MAINT_REMOTELOOP
 #define ZT_MAINT_NONE DAHDI_MAINT_NONE
@@ -132,6 +144,7 @@
 // functions
 #define zt_rbsbits dahdi_rbsbits
 #define zt_alarm_notify dahdi_alarm_notify
+#define zt_alarm_channel dahdi_alarm_channel
 #define zt_receive dahdi_receive
 #define zt_transmit dahdi_transmit
 #define zt_ec_chunk dahdi_ec_chunk
@@ -143,12 +156,21 @@
 #define zt_qevent_lock dahdi_qevent_lock
 
 
+# define WP_ZT_QEVENT_LOCK(chan, event)	dahdi_qevent_lock((chan),(event))
+
 #else
 // zaptel is present
 // we will keep the same old names in wanpipe code, I thought of changing them
 // to something like WP_XX instead of ZT_XX, but I don't see any benefit on it
 // and would make this file bigger 
 #include <zaptel.h>
+#ifndef ZT_GET_PARMS_V1
+#define zt_alarm_channel(a,b) zt_qevent_lock(a,( (b)==ZT_ALARM_NONE )? \
+		ZT_EVENT_NOALARM : ZT_EVENT_ALARM)
+#endif
+
+
+# define WP_ZT_QEVENT_LOCK(chan, event)	zt_qevent_lock(&(chan),(event))
 #endif
 
 #endif	/* __ZAPCOMPAT_H */
