@@ -1526,6 +1526,7 @@ static int wp_tdmv_spanconfig(struct zt_span *span, struct zt_lineconfig *lc)
 	wp_tdmv_softc_t	*wp = NULL;
 	sdla_t		*card = NULL;
 	int		err = 0;
+	wan_smp_flag_t smp_flags;
 
 	WAN_ASSERT2(span == NULL, -ENODEV);
 	WAN_ASSERT2(span->pvt == NULL, -ENODEV);
@@ -1562,7 +1563,9 @@ static int wp_tdmv_spanconfig(struct zt_span *span, struct zt_lineconfig *lc)
 			card->fe.fe_cfg.cfg.te_cfg.sig_mode = WAN_TE1_SIG_CAS;
 		}
 		if (card->wandev.fe_iface.reconfig){
+			card->hw_iface.hw_lock(card->hw,&smp_flags);
 			card->wandev.fe_iface.reconfig(&card->fe);
+			card->hw_iface.hw_unlock(card->hw,&smp_flags);
 		}
 	}
 	span->txlevel = 0;
@@ -1618,6 +1621,17 @@ static int wp_tdmv_spanconfig(struct zt_span *span, struct zt_lineconfig *lc)
 		err = wp_tdmv_startup(span);
 	}
 
+	if (card->wandev.fe_iface.read_alarm) {
+		u32 alarm;
+		card->hw_iface.hw_lock(card->hw,&smp_flags);
+		alarm=card->wandev.fe_iface.read_alarm(&card->fe,WAN_FE_ALARM_READ|WAN_FE_ALARM_UPDATE);
+		if (card->wandev.te_report_alarms) {
+			card->wandev.te_report_alarms(card,alarm);
+		}
+		card->hw_iface.hw_unlock(card->hw,&smp_flags);
+		
+	}
+
 	return err;
 }
 
