@@ -1834,9 +1834,7 @@ STATIC WAN_IRQ_RETVAL sdla_isr (int irq, void* dev_id)
 void wanpipe_open (sdla_t* card)
 {
 	++card->open_cnt;
-#if !defined(LINUX_2_6)
 	MOD_INC_USE_COUNT;
-#endif	
 }
 
 /*============================================================================
@@ -1848,9 +1846,7 @@ void wanpipe_open (sdla_t* card)
 void wanpipe_close (sdla_t* card)
 {
 	--card->open_cnt;
-#if !defined(LINUX_2_6)
 	MOD_DEC_USE_COUNT;
-#endif
 }
 
 sdla_t * wanpipe_find_card_num (int num)
